@@ -44,6 +44,7 @@ class Stream(
         Int("stream-recv-queue-retry-max-count", default=100),
         Float("stream-recv-queue-retry-timeout", default=1.0),
         Int("stream-recv-queue-retry-max-times", default=3),
+        Int("stream-recv-queue-count", default=20),
         String("stream-send-queue", default="mq-master"),
         Int("stream-send-queue-max-length", default=1000),
         Bool("stream-send-queue-trim-immediately", default=False),
@@ -82,6 +83,7 @@ class Stream(
         self.argsDict = self.getArgsDict(*args, **kwargs)
         self.options = self.loadGlobalArguments(self.argsDict)
         self.setBaseServices(self.options)
+        self.ergoLoop.ergoInit()
         self.args = self.loadComponentArguments(self.argsDict)
         return Context.froms(args=self.args)
 
@@ -317,6 +319,7 @@ class StreamCallLoop(StreamMQBaseLoop):
             self.stream.options["stream-recv-queue"],
             group=g.nodeGroup,
             consumer=g.nodeId,
+            count=self.stream.options["stream-recv-queue-count"],
             block=self.stream.options["stream-recv-queue-block"],
             delay=self.stream.options["stream-recv-queue-delay"],
             **kwargs,
@@ -711,6 +714,12 @@ class StreamErgoLoop(StreamMQBaseLoop):
     def getHandler(self):
         return self.stream.callLoop.getHandler()
 
+    def ergoInit(self):
+        if self.ready:
+            logger.debug("Ergo init")
+            from . import ergo
+            ergo.init()
+
     def _ergo_send(self, result, message_id, output):
         from . import ergo
         logger.debug(utils.shorten(f"Send to ergo {output}: {result}", self.DEFAULT_LOGGER_MAX_LENGTH))
@@ -734,8 +743,6 @@ class StreamErgoLoop(StreamMQBaseLoop):
     @runtime.globalrun
     def start(self):
         from . import ergo
-
-        ergo.init()
         logger.debug("Stream Ergo Loop Starting...")
         while True:
             msg, msg_id, in_port = ergo.recv()
